@@ -91,12 +91,12 @@ class StickProtocol():
             PKB['pre_key_id'] = pre_key.key_id
             if not is_sticky:
                 pre_key.delete()
-            elif pre_key:
+            else:
                 pre_key.used = True
                 pre_key.save()
         return PKB
 
-    def get_pre_key_bundles(self, currentUser, users_id):
+    def get_pre_key_bundles(self, current_user, users_id):
         """
         Similar to the above method, but fetches PreKeyBundles of several users at once. This method allows a user to
         communicate their SenderKey to multiple members of a party at once.
@@ -104,9 +104,9 @@ class StickProtocol():
         bundles = {}
         # Make sure the current user is the first in the list. When creating DecryptionSenderKeys client-side to share
         # with other members - there must already be a corresponding EncryptionSenderKey.
-        if currentUser.id in users_id:
-            users_id.remove(currentUser.id)
-            users_id.insert(0, currentUser.id)
+        if current_user.id in users_id:
+            users_id.remove(current_user.id)
+            users_id.insert(0, current_user.id)
 
         to_be_removed = []
         for id in users_id:
@@ -184,7 +184,7 @@ class StickProtocol():
                 if not party:
                     return {'party_exists': False}
                 # A user connected with another user should be authorized
-                if party.user and (user in party.user.connections.all() or user.phone in party.user.contacts):
+                if party.user and user in party.user.connections.all():
                     authorized = True
                 else:
                     if user in party.connections.all():  # A user in the connections list of a party should be authorized
@@ -236,7 +236,8 @@ class StickProtocol():
             key = None
             if sender_key:
                 key = sender_key.key
-                # sender_key.delete()
+                sender_key.key = ''
+                sender_key.save()
             sender_keys[id] = key
         return {'authorized': True, 'sender_keys': sender_keys}
 
@@ -282,7 +283,7 @@ class StickProtocol():
                 elif data['type'] != 'individual':
                     members_ids = self.__create_targets(user, groups_ids, connections_ids)
             party_id = data['party_id']
-        else:  # Sharing to the currentUser's party (currentUsers' profile)
+        else:  # Sharing to the current_user's party (current_users' profile)
             members_ids = connections_ids
             is_individual = data['type'] == 'individual'
             party_id = Party.objects.get(user=user, individual=is_individual).id
@@ -353,13 +354,13 @@ class StickProtocol():
             members_ids.append(user.id)
         return members_ids
 
-    def get_active_stick_id(self, data, currentUser):
+    def get_active_stick_id(self, data, current_user):
         """
         This method gets the active sticky session stick_id associated with a particular party_id that already exists, and
         its current step.
         """
         party_id = data['party_id']
-        sender_keys = EncryptionSenderKey.objects.filter(party_id=party_id, user=currentUser).order_by('-chain_id')
+        sender_keys = EncryptionSenderKey.objects.filter(party_id=party_id, user=current_user).order_by('-chain_id')
         active_sender_key = sender_keys[0]
         response_dict = {}
         if active_sender_key.step < self.session_life_cycle:
@@ -454,31 +455,31 @@ class StickProtocol():
         as well as any of the DSKs the was sent to them, which they can fetch again from the server as needed.
         """
         if user.check_password(data['password_hash']):  # This will create a "double-hash" and verify it
-            signed_pre_keysList = SignedPreKey.objects.filter(user=user)
-            identity_keysList = IdentityKey.objects.filter(user=user)
-            pre_keysList = PreKey.objects.filter(user=user).order_by('-dt_timestamp')
-            sender_keysList = EncryptionSenderKey.objects.filter(user=user)
+            signed_pre_keys_list = SignedPreKey.objects.filter(user=user)
+            identity_keys_list = IdentityKey.objects.filter(user=user)
+            pre_keys_list = PreKey.objects.filter(user=user).order_by('-dt_timestamp')
+            sender_keys_list = EncryptionSenderKey.objects.filter(user=user)
             bundle = {'local_id': user.local_id}
             identity_keys = []
-            for ik in identity_keysList:
+            for ik in identity_keys_list:
                 key = {'id': ik.key_id, 'public': ik.public, 'cipher': ik.cipher, 'salt': ik.salt, 'active': ik.active,
                        'timestamp': ik.timestamp}
                 identity_keys.append(key)
             bundle['identity_keys'] = identity_keys
             signed_pre_keys = []
-            for spk in signed_pre_keysList:
+            for spk in signed_pre_keys_list:
                 key = {'id': spk.key_id, 'public': spk.public, 'cipher': spk.cipher, 'salt': spk.salt,
                        'signature': spk.signature, 'active': spk.active, 'timestamp': spk.timestamp}
                 signed_pre_keys.append(key)
             bundle['signed_pre_keys'] = signed_pre_keys
             pre_keys = []
-            for pre_key in pre_keysList:
+            for pre_key in pre_keys_list:
                 key = {'id': pre_key.key_id, 'public': pre_key.public, 'cipher': pre_key.cipher, 'salt': pre_key.salt,
                        'used': pre_key.used}
                 pre_keys.append(key)
             bundle['pre_keys'] = pre_keys
             sender_keys = []
-            for sender_key in sender_keysList:
+            for sender_key in sender_keys_list:
                 stick_id = sender_key.party_id + str(sender_key.chain_id)
                 key = {'id': sender_key.key_id, 'key': sender_key.key, 'stick_id': stick_id, 'step': sender_key.step,
                        'identity_key_id': sender_key.identity_key.key_id, 'pre_key_id': sender_key.pre_key.key_id}
